pub struct GenericAccount {
pub id: ID,
pub username: String,
pub created: u128,
pub parent_id: String,
pub is_bot: bool,
pub hubs_hashed: Vec<String>,
}Expand description
A version of an Account, uses a hashed version of the list of hubs the user is a member of, the is_bot variable indicates whether or not the account is dedicated to automation/chatbot.
Fields
id: IDusername: Stringcreated: u128parent_id: Stringis_bot: boolhubs_hashed: Vec<String>Trait Implementations
Sourceimpl Clone for GenericAccount
impl Clone for GenericAccount
Sourcefn clone(&self) -> GenericAccount
fn clone(&self) -> GenericAccount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GenericAccount
impl Debug for GenericAccount
Sourceimpl<'de> Deserialize<'de> for GenericAccount
impl<'de> Deserialize<'de> for GenericAccount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for GenericAccount
impl PartialEq for GenericAccount
Sourceimpl Serialize for GenericAccount
impl Serialize for GenericAccount
impl StructuralPartialEq for GenericAccount